@@ -1,5 +1,4 @@
-
-from .mixins import RoutesMixin, BlueprintEventsMixin
+from .common.mixins import RoutesMixin, BlueprintEventsMixin
 
 
 class Blueprint(RoutesMixin, BlueprintEventsMixin):
